==> haskell-strict-0.3.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: strict
version: 0.3.2
id: strict-0.3.2-1XGU2LPrqRE7Qw1PnSNhY5
key: strict-0.3.2-1XGU2LPrqRE7Qw1PnSNhY5
license: BSD3
copyright: (c) 2006-2007 by Roman Leshchinskiy
maintainer: Don Stewart <dons@galois.com>
homepage: http://www.cse.unsw.edu.au/~rl/code/strict.html
synopsis: Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO
    operations.
category: Data, System
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
indefinite: False
exposed-modules:
    Data.Strict Data.Strict.Either Data.Strict.Maybe Data.Strict.Tuple
    System.IO.Strict
abi: 03479adc0b311f646e7569219749154d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/strict-0.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/strict-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/strict-0.3.2
hs-libraries: HSstrict-0.3.2-1XGU2LPrqRE7Qw1PnSNhY5
depends:
    array-0.5.2.0 base-4.10.1.0
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html: /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-0.3.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: strict
version: 0.3.2
id: strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z
key: strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z
license: BSD-3-Clause
copyright: (c) 2006-2007 by Roman Leshchinskiy
maintainer: Don Stewart <dons@galois.com>
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage: http://www.cse.unsw.edu.au/~rl/code/strict.html
synopsis: Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO
    operations.
category: Data, System
abi: 7e8a069e24ca0d6f482c51bd0f02d3b4
exposed: True
exposed-modules:
    Data.Strict Data.Strict.Either Data.Strict.Maybe Data.Strict.Tuple
    System.IO.Strict
import-dirs: /usr/lib/ghc-8.4.2/site-local/strict-0.3.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/strict-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/strict-0.3.2
hs-libraries: HSstrict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z
depends:
    array-0.5.2.0 base-4.11.1.0
abi-depends: array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html: /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
